@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# MySqlPy V1.6.1
+# MySqlPy V1.6.4
 # Author: Luca.Canali@cern.ch
 # 
 #
@@ -10,12 +10,13 @@
 
 from sqlpyPlus import *
 import sys, tempfile, optparse, unittest
+import sqlalchemy
 
 class mysqlpy(sqlpyPlus):
     '''
-MySqlPy V1.6.1 - 'sqlplus in python'
+MySqlPy V1.6.4 - 'sqlplus in python'
 Author: Luca.Canali@cern.ch
-Rev: 1.6.1, 15-Mar-09
+Rev: 1.6.4, 03-Apr-09
 
 Companion of SqlPython, a python module that reproduces Oracle's command line within python
 and sqlpyPlus. Major contributions by Catherine Devlin, http://catherinedevlin.blogspot.com
@@ -144,7 +145,7 @@ which get and run SQL scripts from disk.'''
 
     def do_explain(self,args):
         '''prints the plan of a given statement from the sql cache. 1 parameter: sql_id, see also do_sql '''
-        words = args.sqlit()
+        words = args.split()
         if len(words) > 2 and words[0].lower() == 'plan' and words[1].lower() == 'for':
             self.curs.execute('explain %s' % args)
             print 'Explained.  (see plan table)'
@@ -200,16 +201,16 @@ def run():
     except IndexError:
         pass
     my.cmdloop()
-
+    
 class TestCase(Cmd2TestCase):
     CmdApp = mysqlpy
-    transcriptFileName = 'exampleSession.txt'
 
 if __name__ == '__main__':
     parser = optparse.OptionParser()
     parser.add_option('-t', '--test', dest='unittests', action='store_true', default=False, help='Run unit test suite')
     (callopts, callargs) = parser.parse_args()
     if callopts.unittests:
+        mysqlpy.testfiles = callargs
         sys.argv = [sys.argv[0]]  # the --test argument upsets unittest.main()
         unittest.main()
     else:
