@@ -14,6 +14,15 @@ output_templates = {
   </${tblname}_resultset>
 </xml>"""),
 
+'\\j': genshi.template.NewTextTemplate("""
+{"${tblname}": [
+${',\\n'.join('        {%s}' % ', '.join('"%s": %s' % (colname,
+        ((isinstance(itm,int) or isinstance(itm,float)) and '%s' or '"%s"') % str(itm)
+    ) for (colname, itm) in zip(colnames, row)) for row in rows)}
+    ]
+}"""),  
+
+
 '\\h': genshi.template.MarkupTemplate("""
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns:py="http://genshi.edgewall.org/" xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
@@ -52,7 +61,7 @@ output_templates = {
 {% end %}{% end %}"""),
 
 '\\i': genshi.template.NewTextTemplate("""{% for (rowNum, row) in enumerate(rows) %}
-INSERT INTO $tblname (${', '.join(colnames)}) VALUES (${', '.join(f % r for (r,f) in zip(row, formatters))});{% end %}"""),
+INSERT INTO $tblname (${', '.join(colnames)}) VALUES (${', '.join(formattedForSql(r) for r in row)});{% end %}"""),
 
 '\\c': genshi.template.NewTextTemplate("""
 ${','.join(colnames)}{% for row in rows %}
